@@ -24,8 +24,9 @@ QTEST_MAIN(MovingRangeTest)
 class RangeFeedback : public MovingRangeFeedback
 {
 public:
-    RangeFeedback()
+    RangeFeedback(bool deleteOnInvalid = false)
         : MovingRangeFeedback()
+        , m_deleteOnInvalidation(deleteOnInvalid)
     {
         reset();
     }
@@ -35,8 +36,11 @@ public:
         m_rangeEmptyCalled = true;
     }
 
-    void rangeInvalid(MovingRange * /*range*/) override
+    void rangeInvalid(MovingRange *range) override
     {
+        if (m_deleteOnInvalidation) {
+            delete range;
+        }
         m_rangeInvalidCalled = true;
     }
 
@@ -110,6 +114,7 @@ public:
     }
 
 private:
+    const bool m_deleteOnInvalidation;
     bool m_rangeEmptyCalled;
     bool m_rangeInvalidCalled;
     bool m_mouseEnteredRangeCalled;
@@ -143,7 +148,8 @@ void MovingRangeTest::testFeedbackEmptyRange()
     RangeFeedback rf;
 
     // allow empty
-    MovingRange *range = doc.newMovingRange(Range(Cursor(0, 2), Cursor(1, 4)), KTextEditor::MovingRange::DoNotExpand, KTextEditor::MovingRange::AllowEmpty);
+    std::unique_ptr<MovingRange> range(
+        doc.newMovingRange(Range(Cursor(0, 2), Cursor(1, 4)), KTextEditor::MovingRange::DoNotExpand, KTextEditor::MovingRange::AllowEmpty));
     range->setFeedback(&rf);
     rf.verifyReset();
 
@@ -262,6 +268,7 @@ void MovingRangeTest::testFeedbackInvalidRange()
     QVERIFY(!rf.mouseExitedRangeCalled());
     QVERIFY(!rf.caretEnteredRangeCalled());
     QVERIFY(!rf.caretExitedRangeCalled());
+    delete range;
 }
 
 // tests:
@@ -432,6 +439,7 @@ void MovingRangeTest::testFeedbackMouse()
     QTest::qWait(200); // process mouse events. do not move mouse manually
     QVERIFY(!rf.mouseEnteredRangeCalled());
     QVERIFY(rf.mouseExitedRangeCalled());
+    delete range;
 }
 
 void MovingRangeTest::testLineRemoved()
@@ -700,3 +708,120 @@ void MovingRangeTest::testMultiblockRangeWithLineUnwrapping()
     delete range;
     doc.buffer().rangesForLine(0, nullptr, false);
 }
+
+void MovingRangeTest::testRangeSurvivesDocument()
+{
+    KTextEditor::MovingRange *range;
+    {
+        KTextEditor::DocumentPrivate doc;
+        doc.setText(QStringLiteral("abc"));
+        range = doc.newMovingRange({0, 0, 0, 2});
+        QVERIFY(range);
+    }
+    // ensure range is invalid
+    QCOMPARE(range->toRange(), KTextEditor::Range::invalid());
+    QVERIFY(!range->toLineRange().isValid());
+    QVERIFY(!range->document());
+    // try to modify this range, shouldn't crash
+    range->setRange({1, 2, 3, 4});
+    range->setAttribute(KTextEditor::Attribute::Ptr(new KTextEditor::Attribute));
+    RangeFeedback rf;
+    range->setFeedback(&rf);
+    range->setZDepth(1);
+    // range remains invalid as there is no document its bound to
+    QCOMPARE(range->toRange(), KTextEditor::Range(-1, -1, -1, -1));
+    QVERIFY(!range->attribute());
+    QVERIFY(!range->feedback());
+    delete range;
+}
+
+void MovingRangeTest::testRangeWithDynAttrNoCrash()
+{
+    KTextEditor::DocumentPrivate doc;
+    doc.setText(QStringLiteral("abc\ndef\nghi"));
+    KTextEditor::ViewPrivate *view = static_cast<KTextEditor::ViewPrivate *>(doc.createView(nullptr));
+    std::unique_ptr<KTextEditor::MovingRange> range(doc.newMovingRange({0, 0, 0, 2}, MovingRange::DoNotExpand));
+    auto attr = KTextEditor::Attribute::Ptr(new KTextEditor::Attribute());
+    auto dattr = KTextEditor::Attribute::Ptr(new KTextEditor::Attribute());
+    attr->setDynamicAttribute(KTextEditor::Attribute::ActivateCaretIn, dattr);
+    range->setAttribute(attr);
+
+    view->setCursorPosition({0, 0});
+    // cursor moves
+    view->cursorRight();
+    // range is deleted for some reason
+    range.reset();
+    // cursor moves
+    view->cursorRight();
+    // no crashes
+}
+
+void MovingRangeTest::testNoCrashIfFeedbackWasClearedBeforeDtor()
+{
+    KTextEditor::DocumentPrivate doc;
+    doc.setText(QStringLiteral("abc\ndef\nghi"));
+    KTextEditor::ViewPrivate *view = static_cast<KTextEditor::ViewPrivate *>(doc.createView(nullptr));
+    std::unique_ptr<KTextEditor::MovingRange> range(doc.newMovingRange({0, 0, 0, 2}, MovingRange::DoNotExpand));
+    RangeFeedback rf;
+    range->setFeedback(&rf);
+
+    view->setCursorPosition({0, 0});
+    // cursor moves
+    view->cursorRight();
+    // feedback is cleared
+    range->setFeedback(nullptr);
+    range.reset();
+    // cursor moves
+    view->cursorRight();
+    // no crash
+}
+
+void MovingRangeTest::testNoCrashIfDynAttrWasClearedBeforeDtor()
+{
+    KTextEditor::DocumentPrivate doc;
+    doc.setText(QStringLiteral("abc\ndef\nghi"));
+    KTextEditor::ViewPrivate *view = static_cast<KTextEditor::ViewPrivate *>(doc.createView(nullptr));
+    std::unique_ptr<KTextEditor::MovingRange> range(doc.newMovingRange({0, 0, 0, 2}, MovingRange::DoNotExpand));
+    auto attr = KTextEditor::Attribute::Ptr(new KTextEditor::Attribute());
+    auto dattr = KTextEditor::Attribute::Ptr(new KTextEditor::Attribute());
+    attr->setDynamicAttribute(KTextEditor::Attribute::ActivateCaretIn, dattr);
+    range->setAttribute(attr);
+
+    view->setCursorPosition({0, 0});
+    // cursor moves
+    view->cursorRight();
+    // attr is cleared
+    range->setAttribute({});
+    range.reset();
+    // cursor moves
+    view->cursorRight();
+    // no crash
+}
+
+void MovingRangeTest::testNoCrashWithMultiblockRange()
+{
+    KTextEditor::DocumentPrivate doc;
+    KTextEditor::ViewPrivate *view = static_cast<KTextEditor::ViewPrivate *>(doc.createView(nullptr));
+    const QStringList lines(130, QStringLiteral("text"));
+    doc.setText(lines);
+    QCOMPARE(doc.lines(), 130);
+    // clang-format off
+    std::unique_ptr<KTextEditor::MovingRange> range(doc.newMovingRange({
+        63, 1, // in block 0 last line
+        64, 2 // in block 1 first line
+    }));
+    // expect that its multiline
+    QVERIFY(doc.buffer().hasMultlineRange(range.get()));
+    // clang-format on
+    // place the cursor on col 0 of first line block-1
+    view->setCursorPosition({64, 0});
+    // trigger a line unwrap
+    view->backspace();
+    // expect that its no longer multiline
+    QVERIFY(!doc.buffer().hasMultlineRange(range.get()));
+
+    // delete the range
+    range.reset();
+    // move the cursor, we shouldnt crash
+    view->cursorLeft();
+}
