@@ -230,7 +230,7 @@ void TextBlock::unwrapLine(int line, TextBlock *previousBlock, int fixStartLines
                 auto range = cursor->kateRange();
                 if (range && !range->isValidityCheckRequired()) {
                     range->setValidityCheckRequired();
-                    changedRanges.push_back({range, false});
+                    changedRanges.push_back({range, range->spansMultipleBlocks()});
                 }
             }
         }
@@ -569,70 +569,14 @@ void TextBlock::mergeBlock(TextBlock *targetBlock)
     clearLines();
 }
 
-void TextBlock::deleteBlockContent()
-{
-    // kill cursors, if not belonging to a range
-    // we can do in-place editing of the current set of cursors as
-    // we remove them before deleting
-    for (auto it = m_cursors.begin(); it != m_cursors.end();) {
-        auto cursor = *it;
-        if (!cursor->kateRange()) {
-            // remove it and advance to next element
-            it = m_cursors.erase(it);
-
-            // delete after cursor is gone from the set
-            // else the destructor will modify it!
-            delete cursor;
-        } else {
-            // keep this cursor
-            ++it;
-        }
-    }
-
-    // kill lines
-    clearLines();
-}
-
-void TextBlock::clearBlockContent(TextBlock *targetBlock)
-{
-    // move cursors, if not belonging to a range
-    // we can do in-place editing of the current set of cursors
-    for (auto it = m_cursors.begin(); it != m_cursors.end();) {
-        auto cursor = *it;
-        if (!cursor->kateRange()) {
-            cursor->m_column = 0;
-            cursor->m_line = 0;
-            cursor->m_block = targetBlock;
-            targetBlock->m_cursors.push_back(cursor);
-
-            // remove it and advance to next element
-            it = m_cursors.erase(it);
-        } else {
-            // keep this cursor
-            ++it;
-        }
-    }
-
-    // kill lines
-    clearLines();
-}
-
-QList<TextRange *> TextBlock::rangesForLine(int line, KTextEditor::View *view, bool rangesWithAttributeOnly) const
-{
-    QList<TextRange *> ranges;
-    rangesForLine(line, view, rangesWithAttributeOnly, ranges);
-    return ranges;
-}
-
 void TextBlock::rangesForLine(const int line, KTextEditor::View *view, bool rangesWithAttributeOnly, QList<TextRange *> &outRanges) const
 {
-    outRanges.clear();
     const int lineInBlock = line - startLine(); // line number in block
-    for (auto cursor : std::as_const(m_cursors)) {
+    for (TextCursor *cursor : std::as_const(m_cursors)) {
         if (!cursor->kateRange()) {
             continue;
         }
-        auto range = cursor->kateRange();
+        TextRange *range = cursor->kateRange();
         if (rangesWithAttributeOnly && !range->hasAttribute()) {
             continue;
         }
@@ -647,18 +591,15 @@ void TextBlock::rangesForLine(const int line, KTextEditor::View *view, bool rang
             continue;
         }
 
-        // simple case
-        if (cursor->lineInBlock() == lineInBlock) {
-            outRanges.append(range);
-        }
-        // if line is in the range, ok
-        else if (range->startInternal().lineInternal() <= line && line <= range->endInternal().lineInternal()) {
+        if (
+            // simple case
+            (cursor->lineInBlock() == lineInBlock) ||
+            // if line is in the range, ok
+            (range->startInternal().lineInternal() <= line && line <= range->endInternal().lineInternal())
+        ) {
             outRanges.append(range);
         }
     }
-    std::sort(outRanges.begin(), outRanges.end());
-    auto it = std::unique(outRanges.begin(), outRanges.end());
-    outRanges.erase(it, outRanges.end());
 }
 
 void TextBlock::markModifiedLinesAsSaved()
