@@ -159,28 +159,12 @@ public:
     void mergeBlock(TextBlock *targetBlock);
 
     /**
-     * Delete the block content, delete all lines and delete all cursors not bound to ranges.
-     * This is used in destructor of TextBuffer, for fast cleanup. Only stuff remaining afterwards are cursors which are
-     * part of a range, TextBuffer will delete them itself...
-     */
-    void deleteBlockContent();
-
-    /**
-     * Clear the block content, delete all lines, move all cursors not bound to range to given block at 0,0.
-     * This is used by clear() of TextBuffer.
-     * @param targetBlock empty target block for cursors
-     */
-    void clearBlockContent(TextBlock *targetBlock);
-
-    /**
-     * Return all ranges in this block which might intersect the given line.
+     * Append to outRanges addresses of all ranges in this block which might intersect the given line.
      * @param line                          line to check intersection
      * @param view                          only return ranges associated with given view
      * @param rangesWithAttributeOnly       ranges with attributes only?
-     * @return list of possible candidate ranges
+     * @param outRanges                     where to append results
      */
-    KTEXTEDITOR_EXPORT QList<TextRange *> rangesForLine(int line, KTextEditor::View *view, bool rangesWithAttributeOnly) const;
-
     KTEXTEDITOR_NO_EXPORT void rangesForLine(int line, KTextEditor::View *view, bool rangesWithAttributeOnly, QList<TextRange *> &outRanges) const;
 
     /**
