@@ -72,6 +72,16 @@ void KateCompletionTree::setScrollingEnabled(bool enabled)
     m_scrollingEnabled = enabled;
 }
 
+int KateCompletionTree::textColumnOffset() const
+{
+    QStyleOptionViewItem item;
+    item.index = currentIndex();
+    initViewItemOption(&item);
+    int margins = style()->pixelMetric(QStyle::PM_FocusFrameHMargin) * 3;
+    int nameColumn = kateModel()->translateColumn(KTextEditor::CodeCompletionModel::Name);
+    return margins + item.decorationSize.width() + columnViewportPosition(nameColumn);
+}
+
 void KateCompletionTree::scrollContentsBy(int dx, int dy)
 {
     if (m_scrollingEnabled) {
@@ -94,7 +104,7 @@ void KateCompletionTree::resizeColumnsSlot()
         resizeColumns();
 
         if (!widget()->docTip()->isHidden()) {
-            widget()->docTip()->updatePosition();
+            widget()->docTip()->updatePosition(widget());
         }
     }
 }
@@ -185,7 +195,7 @@ void KateCompletionTree::resizeColumns(bool firstShow, bool forceResize)
     auto totalColumnsWidth = 0;
     auto originalViewportWidth = viewport()->width();
 
-    const int maxWidth = (widget()->view()->screen()->availableGeometry().width()) / 2;
+    const int maxWidth = (widget()->parentWidget()->geometry().width()) / 2;
 
     /// Step 2: Update column-sizes
     // This contains several hacks to reduce the amount of resizing that happens. Generally,
